.. kpm documentation master file, created by
   sphinx-quickstart on Wed Aug 24 23:44:20 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to kpm's documentation!
===============================

Contents:

.. toctree::
   :maxdepth: 2

   test1/kpm.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. automodule:: kpm
   :members:

.. automodule:: kpm.api.impl.registry
   :members:

.. automodule:: kpm.api.impl.builder
   :members:
